@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2013 Jeffrey Stedfast
+ *  Copyright (C) 2000-2022 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -58,21 +58,19 @@ typedef struct _GMimeContentDispositionClass GMimeContentDispositionClass;
 /**
  * GMimeContentDisposition:
  * @parent_object: parent #GObject
- * @param_hash: parameter hash table keyed by param name
- * @params: a #GMimeParam list
  * @disposition: disposition
+ * @params: a #GMimeParam list
  *
  * A data structure representing a Content-Disposition.
  **/
 struct _GMimeContentDisposition {
 	GObject parent_object;
 	
-	GHashTable *param_hash;
-	GMimeParam *params;
-	
-	gpointer priv;
-	
 	char *disposition;
+	GMimeParamList *params;
+	
+	/* < private > */
+	gpointer changed;
 };
 
 struct _GMimeContentDispositionClass {
@@ -84,20 +82,21 @@ GType g_mime_content_disposition_get_type (void);
 
 
 GMimeContentDisposition *g_mime_content_disposition_new (void);
-GMimeContentDisposition *g_mime_content_disposition_new_from_string (const char *str);
+GMimeContentDisposition *g_mime_content_disposition_parse (GMimeParserOptions *options, const char *str);
 
 void g_mime_content_disposition_set_disposition (GMimeContentDisposition *disposition, const char *value);
 const char *g_mime_content_disposition_get_disposition (GMimeContentDisposition *disposition);
 
-void g_mime_content_disposition_set_params (GMimeContentDisposition *disposition, GMimeParam *params);
-const GMimeParam *g_mime_content_disposition_get_params (GMimeContentDisposition *disposition);
+GMimeParamList *g_mime_content_disposition_get_parameters (GMimeContentDisposition *disposition);
 
 void g_mime_content_disposition_set_parameter (GMimeContentDisposition *disposition,
-					       const char *attribute, const char *value);
+					       const char *name, const char *value);
 const char *g_mime_content_disposition_get_parameter (GMimeContentDisposition *disposition,
-						      const char *attribute);
+						      const char *name);
 
-char *g_mime_content_disposition_to_string (GMimeContentDisposition *disposition, gboolean fold);
+gboolean g_mime_content_disposition_is_attachment (GMimeContentDisposition *disposition);
+
+char *g_mime_content_disposition_encode (GMimeContentDisposition *disposition, GMimeFormatOptions *options);
 
 G_END_DECLS
 
